%%
%% This is file `buthesis.cls',
%% 
%% Bilkent University
%% MS and PhD Thesis Style 
%%
%% by Umit V. Catalyurek
%% 
%% October 7, 1999
%% fi
%% Edited by Akif Burak Tosun
%% July 20, 2012
%%
%% Edited by Feysel Yalcin Yamaner
%% June 24, 2016
%%
%% Edited by Ahmet Yazar
%% December 8, 2016

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{buthesis}

% --- base class and extensions..
\LoadClass[12pt,a4paper]{report} 
\RequirePackage{graphicx}
 
\usepackage[raggedright]{titlesec}

% For the fontspec to work, the compiler should be xelatex or lualatex (pdflatex doesn't work)
\usepackage{fontspec}
\setromanfont{Times New Roman}  % need to use \bfseries for bold
\setmainfont{Times New Roman}

 %%%---chapter----%% Updated May: 2021 by Nann Win Moe Thet
 %For the table of contents, list of figures, list of tables, list of symbols, abbreviations, abstract, long indented quotes that are exceeding 40 words, multi-line and sub-level headings, figure and table captions, biography, liography, and footnotes must be written in single line spacing.
 
 \titleformat{\chapter}[block]{\bfseries\fontsize{12pt}{12}}{}{0em}{\MakeUppercase}
 \titlespacing{\chapter}{0pt}{-10pt}{8pt}% first level titles

 %%%---section----%%Updated June: 2021 by Nann Win Moe Thet
\titleformat{\section}{\fontsize{12pt}{12}	\bfseries}{\thesection.}{1em}{\capitalisewords}
%\titlespacing{\section}{0pt}{18pt}{12pt} % second level titles [18pt before 12pt after]

%%%---subsection/subsubsection----%%Updated May: 2021 by Nann Win Moe Thet
 \titleformat{\subsection}{\fontsize{12pt}{12} \bfseries\selectfont}{\thesubsection.}{1em}{}
\titleformat{\subsubsection}{\fontsize{12pt}{12} \bfseries\selectfont}{\thesubsubsection.}{1em}{}


%%%%%%%%%%%%%%%%%%%%%%% for figure/table spacing updated June
% The default values in the article document class with the 10pt option are:
% \textfloatsep — distance between floats on the top or the bottom and the text;
% \floatsep — distance between two floats;
% \intextsep — distance between floats inserted inside the page text (using h) and the text proper.

% \textfloatsep: 20.0pt plus 2.0pt minus 4.0pt;
% \floatsep: 12.0pt plus 2.0pt minus 2.0pt;
% \intextsep: 12.0pt plus 2.0pt minus 2.0pt.

%12pt before, 6pt after for table and figure in the text

\setlength\intextsep{12pt plus 1.0pt minus 2.0pt} %% change the point accordingly




%%%%-----Bibliography---------%%%%%%%%Updated June: 2021 by Nann Win Moe Thet

\usepackage{etoolbox} 
\patchcmd{\thebibliography} %Note: although footnotes and bibliography are single-spaced, between their entries, 8 pt spacing is required after entries.
  {\settowidth}
  {\setlength{\itemsep}{8pt plus 0pt}\settowidth}
  {}{}
\apptocmd{\thebibliography}
  {\fontsize{12pt}{12}}
  {}{}

\renewcommand\bibname{\MakeUppercase{BIBLIOGRAPHY}} %% Updated  rename uppercase title
%citation 
\def\citepunct{], [}
\def\citedash{]--[}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage[dotinlabels]{titletoc}
\dottedcontents{section}[3.8em]{}{2.3em}{1pc}
\dottedcontents{subsection}[3.8em]{}{2.3em}{1pc}
\dottedcontents{subsubsection}[3.8em]{}{2.3em}{1pc}
\dottedcontents{chapter}[3.8em]{}{2.3em}{1pc}



%% -------- the following variables must be supplied
\def\director#1{\gdef\@director{#1}}
\def\thesistype#1{\gdef\@thesistype{#1}} 
\def\teztipi#1{\gdef\@teztipi{#1}} 

\def\keywords#1{\gdef\@keywords{#1}}
\def\anahtarsoz#1{\gdef\@anahtarsoz{#1}}

\def\dept#1{\gdef\@dept{#1}}
\def\bolum#1{\gdef\@bolum{#1}}
\def\principaladviser#1{\gdef\@principaladviser{#1}}
\def\tezyoneticisi#1{\gdef\@tezyoneticisi{#1}}
\def\advis@r{Adviser}
\def\principaladvisor#1{\gdef\@principaladviser{#1}\gdef\advis@r{Advisor}}
\def\firstreader#1{\gdef\@firstreader{#1}}
\def\secondreader#1{\gdef\@secondreader{#1}}
% third and fourth reader are required in PhD only
\def\thirdreader#1{\gdef\@thirdreader{#1}}
\def\fourthreader#1{\gdef\@fourthreader{#1}}
\def\fifthreader#1{\gdef\@fifthreader{#1}}
\def\submitdate#1{\gdef\@submitdate{#1}}
\def\submitmonth#1{\gdef\@submitmonth{#1}}
\def\tarih#1{\gdef\@tarih{#1}}
\def\baslik#1{\gdef\@baslik{#1}}




%% height related measures - original
% \voffset 0mm
% \topmargin -5mm
% \headsep 15mm
% \textheight 220mm 




%% height related measures - modified
% \voffset 0mm
% \topmargin 0mm
% \headsep 0mm
% \textheight 247mm 

% %% width releatex measures
% \hoffset 0mm
% \textwidth 145mm
% % \textwidth 150mm
% \oddsidemargin 0.6in \evensidemargin 0.6in
% \marginparwidth 40pt \marginparsep 12pt

\usepackage[bottom=2.5cm,top=2.5cm, left=3.5cm, right=2.5cm]{geometry}

% Updated the parskip and linespacing - 3/6/2021
\parskip 6pt \footskip 9mm
\tolerance=6000
\brokenpenalty=10000
\usepackage{setspace}
\setstretch{1.5}

% \renewcommand{\baselinestretch}{1.3} %In LaTeX 1.3=1.5 spacing
% \renewcommand{\linespread}{10}   %In LaTeX 1.3=1.5 spacing

%\usepackage{tocstyle}
%\newcommand{\autodot}{.}

 
 %% figure,table,equation format Edit Nann-----%%%    Updated May: 2021 by Nann Win Moe Thet
\def\thefigure{\bfseries\thechapter.\@arabic\c@figure\bfseries}
\def\thetable{\bfseries{\thechapter.\@arabic\c@table}}
\def\theequation{\bfseries {\thechapter.\arabic{equation}}}
\usepackage[chapter]{algorithm}
\def\thealgorithm{\bfseries{\thechapter.\arabic{algorithm}}}



% %%%%%%%%%%%% add new Nann%%%%%%%%%%    Updated May: 2021 by Nann Win Moe Thet
%\RequirePackage[titles]{tocloft}
\RequirePackage[titles]{tocloft}
\renewcommand\cftchapfont{\bfseries\fontsize{12pt}{12}}
\renewcommand\cftchappagefont{\bfseries\fontsize{12pt}{12}}
\renewcommand\cftsecfont{\fontsize{12pt}{12}}
\renewcommand\cftsecpagefont{\fontsize{12pt}{12}}
\renewcommand\cftsubsecfont{\fontsize{12pt}{12}}
\renewcommand\cftsubsecpagefont{\fontsize{12pt}{12}}

 \setlength{\cftbeforechapskip}{0pt}
 \setlength{\cftbeforesecskip}{0pt}
% \renewcommand\cftchapafterpnum{\vspace{-7pt}}
 %\renewcommand\cftsecafterpnum{\vspace{-7pt}}
% \renewcommand\cftsubsecafterpnum{\vspace{-7pt}}
%%%%%--------------------TOC dot after chapter number-----
\renewcommand{\cftchapaftersnum}{.}
\renewcommand{\cftsecaftersnum}{.}
\renewcommand{\cftsubsecaftersnum}{.}
\renewcommand{\cftsubsubsecaftersnum}{.}
 \setlength{\cftsecindent}{4mm}  % toc sect/sub section indenting
 \setlength{\cftsubsecindent}{8.5mm}
\setlength{\cftsubsubsecindent}{20mm}

%\dottedcontents{section}[1.5em]{}{1.3em}{.6em}
\addtolength{\cftchapnumwidth}{0.5em}  %% in toc spacing between chapter no and chapter 
\addtolength{\cftsecnumwidth}{1em}
\addtolength{\cftsubsecnumwidth}{1em}
\addtolength{\cftsubsubsecnumwidth}{1em}




\newlength{\mylen}
%with dots for chapters in toc
% \@dotsep = 4.5 default
\renewcommand{\cftchapdotsep}{-2}
\renewcommand{\cftsecdotsep}{1}
\renewcommand{\cftsubsecdotsep}{1}
\renewcommand{\cftsubsubsecdotsep}{1}


%\addtolength{\cftsectionnumwidth}{4em}
% ...similar to 
 \renewcommand{\cftdotsep}{1}
%------------Figure TOC----------%  Updated May: 2021 by Nann Win Moe Thet


%%%%%%%%%%%%%%new added list of figure%%%%%%%%%%%%%%%5
\cftsetrmarg{0pt}% <- Set right margin to zero
\renewcommand\cftfigpresnum{\bfseries{\figurename}~}% <- Prepend `Figure' in front of number
\renewcommand\cftfigfont{\fontsize{12pt}{12}}
\renewcommand\cftfigpagefont{\fontsize{12pt}{12}}
\renewcommand\cftfigaftersnum{\bfseries{:}}% <- Append `:' behind number
\renewcommand\cftfigaftersnumb{\hspace{5em}}% <- Add enough space to start caption text
\cftsetindents{figure}{0pt}{0pt}% <- Set left indents to zero


% \renewcommand{\cftfigpresnum}{\hspace{-18pt}\bfseries{\figurename}\enspace}
% \renewcommand{\cftfigaftersnum}{\bfseries{:}}
% \renewcommand\cftfigfont{\fontsize{12pt}{12}}
% \renewcommand\cftfigpagefont{\fontsize{12pt}{12}}
% %\settowidth{\mylen}{\cftfigpresnum\cftfigaftersnum}
% %\renewcommand\cftfigafterpnum{\vspace{-7pt}}
% \addtolength{\cftfignumwidth}{1.8em}
%------------Table TOC----------%  Updated May: 2021 by Nann Win Moe Thet
\renewcommand{\cfttabpresnum}{\hspace{-18pt}\bfseries{\tablename}\enspace}
\renewcommand{\cfttabaftersnum}{\bfseries{:}}
\renewcommand\cfttabfont{\fontsize{12pt}{12}}
\renewcommand\cfttabpagefont{\fontsize{12pt}{12}}
\settowidth{\mylen}{\cfttabpresnum\cfttabaftersnum}
\addtolength{\cfttabnumwidth}{1em}
\renewcommand{\cftchapleader}{\bfseries\cftdotfill{\cftdotsep}} % fills 
%\renewcommand\cfttabafterpnum{\vspace{-7pt}}





%---------Abbreviations TOC-----------%  Updated May: 2021 by Nann Win Moe Thet
\RequirePackage[nopostdot,nonumberlist,style=super, nogroupskip]{glossaries}
\makeglossaries
%% modsuper glossary display style%%  Updated May: 2021 by Nann Win Moe Thet
\newglossarystyle{modsuper}{%
\glossarystyle{super}%
\renewcommand{\glsgroupskip}{}%
\renewcommand*{\glossaryentryfield}[5]{%
\hspace{-5pt}\glsentryitem{##1}\glstarget{##1}{##2} & \hspace{0.5cm}{:}##3\glspostdescription\space ##5\\[2pt]}%
}
\renewcommand{\glsnamefont}[1]{\bfseries{#1}} % bold 
\setglossarystyle{modsuper}% use new style
\setlength{\glsdescwidth}{1\textwidth}


%%%%%%%%%%%%%%%%%%

 
\def\@xfloat#1[#2]{\ifhmode \@bsphack\@floatpenalty -\@Mii\else
   \@floatpenalty-\@Miii\fi\def\@captype{#1}\ifinner
      \@parmoderr\@floatpenalty\z@
    \else\@next\@currbox\@freelist{\@tempcnta\csname ftype@#1\endcsname
       \multiply\@tempcnta\@xxxii\advance\@tempcnta\sixt@@n
       \@tfor \@tempa :=#2\do
                        {\if\@tempa h\advance\@tempcnta \@ne\fi
                         \if\@tempa t\advance\@tempcnta \tw@\fi
                         \if\@tempa b\advance\@tempcnta 4\relax\fi
                         \if\@tempa p\advance\@tempcnta 8\relax\fi
         }\global\count\@currbox\@tempcnta}\@fltovf\fi
%    \global\setbox\@currbox\vbox\bgroup
    \global\setbox\@currbox\color@vbox\normalcolor\vbox\bgroup 
    \def\baselinestretch{1}\@normalsize
    \boxmaxdepth\z@
    \hsize\columnwidth \@parboxrestore}
\long\def\@footnotetext#1{\insert\footins{\def\baselinestretch{1}\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth \@parboxrestore
   \edef\@currentlabel{\csname p@footnote\endcsname\@thefnmark}\@makefntext
    {\rule{\z@}{\footnotesep}\ignorespaces
      #1\strut}}}
 


\def\@submitdate{\ifcase\the\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space \number\the\year}
\ifnum\month=12
    \@tempcnta=\year \advance\@tempcnta by 1
\fi

\def\titlepageMS{%
  \setstretch{2.2}
        \thispagestyle{empty}%
        \null\vskip1in%
        \begin{center}
                {\fontsize{12pt}{12} \bf\uppercase\expandafter{\@title}}
        \end{center}
        \vfill
        \begin{center}
                {\fontsize{12pt}{12} 
                % I edited
%                \sc a thesis \\ 
%                submitted to the department of \lowercase\expandafter{\@dept}\\
%                and the graduate school of engineering and natural sciences\\
%                of istanbul medipol university\\
%               in partial fulfillment of the requirements\\
%                for the degree of\\
%                master of science \\
                \sc a thesis submitted to\\
                the graduate school of \\ engineering and natural sciences\\
		of istanbul medipol university\\
                in partial fulfillment of the requirements for\\
                the degree of\\
                master of science \\
		in\\
		\lowercase\expandafter{\@dept}\\
                }
        \end{center}
        \vspace{3cm}
        \begin{center}
                {\fontsize{12pt}{12} 
                \rm By\\
                \@author\\
                \@submitdate\\
                }
        \end{center}\vskip.5in\newpage}

\def\titlepagePhD{%
        \thispagestyle{empty}%
        \setstretch{2.2}
        \null  \vskip 1.8cm%
        \begin{minipage}{5.5in}    
        \begin{center}
                \fontsize{12pt}{12}  \bfseries\uppercase\expandafter{\@title}
          \end{center}
         \end{minipage}
        \vspace{85pt}%
        \begin{center}
             \setstretch{1.85}
                {\fontsize{12pt}{12} 
            \MakeUppercase{a dissertation submitted to\\
		the graduate school of \\ engineering and natural sciences\\
                of istanbul medipol university\\
                in partial fulfillment of the requirements for\\
                the degree of\\
		doctor of philosophy\\
                in\\
                \expandafter{\@dept}\\}
                }
        \end{center}
        \vspace{62pt}%
        \begin{center}
              \setstretch{2.5}
                {\fontsize{12pt}{12} 
                \rm By\\
                \@author\\
                \@submitmonth\\
                }
        \end{center}\vskip.5in\newpage}
\long\def\signatureMS#1{ 
     \setstretch{1.5}        
\begin{minipage}{5in}
\parindent 0pt
\MakeUppercase{\@title\\}
By
\@author\\
\@submitdate\\
\end{minipage}\\
We certify that we have read this thesis and that in our opinion
it is fully adequate, in scope and in quality, as a thesis for the degree
of Master of Science.

\begin{center}
\begin{minipage}{5.5in}
\parindent=0pt
\par
\vspace{0.5in}
%\hspace*{1.8cm}
\hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt\\#1}}
\end{minipage}
\end{center}}

\long\def\signatureMSS#1{
\begin{center}
\begin{minipage}{5.5in}
\parindent=0pt
\par
\vspace{0.5in}
\hspace*{1.8cm}
\hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt\\#1}}
\end{minipage}
\end{center}}



\def\signaturepageMS{
  \setstretch{1.5}
        \thispagestyle{plain}
        \signatureMS{\@principaladviser (\advis@r)}
        \vskip 1cm
	\signatureMSS{\@firstreader}
        \vskip 1cm
        \signatureMSS{\@secondreader}
%        \vspace*{1cm}
	\vfill	
        %\begin{center}
        %\begin{minipage}{5in}
        %Approved by the Graduate School of Engineering and Natural Sciences:\par
        %\vspace{1.0in}
        %\hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt\\
                       % \@director \\ Director of the Graduate School of Engineering and Natural Sciences}}
        %\end{minipage}
        %\end{center} 
	\newpage}


\long\def\signaturePhDintro#1{% edited  Updated May: 2021 by Nann Win Moe Thet
%\begin{minipage}{5in}
  \setstretch{1.5}
\parskip 0pt
\parindent 0pt
\MakeUppercase{\@title}\vspace{5pt}\\
By
\@author\vspace{5pt}\\
\@submitdate\vspace{5pt}\\
%\end{minipage}\\
We certify that we have read this dissertation and that in our opinion
it is fully adequate, in scope and in quality, as a dissertation for the degree
of Doctor of Philosophy.
}

\long\def\signaturePhD#1{%  Updated May: 2021 by Nann Win Moe Thet
%\begin{center}
%\begin{minipage}{5.5in}
\parindent=0pt
\par
\vspace{0.7in}
\hspace*{0.5cm}
%\hspace*{0.5cm}
\hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt\vspace{10pt}\\#1}}
%\end{minipage}
%\end{center}
}

 \long\def\signaturePhDD#1{   %%Updated May: 2021 by Nann Win Moe Thet
         %%\begin{minipage}{5in}
         \parindent=0pt
         \par
        \vspace{0.6in}
        \hspace*{0.6cm}
        \hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt\vspace{10pt}\\#1}}
        %\end{minipage}
        %\end{center} 
        }
 
 
\def\signaturepagePhD{%
        \thispagestyle{plain}
        \signaturePhDintro{}
           \vspace{0.2cm}
        \signaturePhD{\@principaladviser(\advis@r)}
          \vspace{0.2cm}
        \signaturePhDD\@firstreader
           \vspace{0.2cm}
        \signaturePhDD\@secondreader
	       \vspace{0.2cm}
        \signaturePhDD\@thirdreader
           \vspace{0.2cm}
        \signaturePhDD\@fourthreader
           \vspace{0.2cm}
        %\signaturePhDD\@fifthreader % additional 
        \vfill 
         \begin{center}
        \begin{minipage}{5in}
        \vspace{0.2cm}
        Approved by the Graduate School of Engineering and Natural Sciences:\par
        \vspace{0.6in}
        \hbox to 4in{\hfil\shortstack{\vrule width 3in height 0.4pt     \vspace{10pt}\\
        \@director \vspace{20pt} \\  
         Director of the Graduate School of Engineering and Natural Sciences}}
        \end{minipage}
        \end{center}  
	\newpage}
 
\parskip 0.5cm
\parindent 0.5cm

\renewenvironment{abstract}{%   Updated May: 2021 by Nann Win Moe Thet
   \thispagestyle{plain}%
     \null   \vskip 2.1cm%
          \setstretch{1}
   %\setlength{\baselineskip}{6mm} %% updated {6mm}
  % \renewcommand{\baselinestretch}{1} % scaling the default baselineskip
   \parskip  6pt %0.5cm 
\parindent 0pt
   \begin{center}
    \begin{minipage}{5.5in}    
        \begin{center}
                \fontsize{12pt}{12}  \bfseries\uppercase\expandafter{\@title}
          \end{center}
         \end{minipage}  \\
     \vspace{0.5cm} 
     {\bfseries \fontsize{12pt}{12} ABSTRACT} \\
     \vspace*{0.5cm}
     \@author   \vspace{0.3cm} \\
     \@thesistype  in \@dept  \vspace{0.3cm}\\
     Advisor: \@principaladviser  \vspace{0.3cm}\\
     \@submitdate \vspace{-0.5cm} \\
   \end{center}
  \noindent\ignorespaces}{{\vfill \noindent {Keywords:} {\@keywords}.} \newpage}

\newenvironment{ozet}{%  Updated May: 2021 by Nann Win Moe Thet
   \thispagestyle{plain}%
     \null   \vskip 2.1cm%
      \setstretch{1}
      %\setlength{\baselineskip}{6mm} %% updated {6mm}
 %\renewcommand{\baselinestretch}{1} % scaling the default baselineskip
   \parskip 6pt %0.5cm % 7pt%
\parindent 0pt
   \begin{center}
        \begin{minipage}{5.5in}    
        \begin{center}
                \fontsize{12pt}{12}  \bfseries\uppercase\expandafter{\@baslik}
          \end{center}
         \end{minipage}  \\
     \vspace{0.5cm} 
     {\bfseries \fontsize{12pt}{12} \"{O}ZET} \\
     \vspace*{0.5cm}
     \@author        \vspace{0.3cm} \\
     \@bolum, \@teztipi      \vspace{0.3cm} \\
     Tez Dan{\i\c s}man{\i }: \@tezyoneticisi  \vspace{0.3cm} \\
     \@tarih  \vspace{-0.5cm}  \\
   \end{center}
  \noindent\ignorespaces} {{\vfill \noindent {Anahtar s\"{o}zc\"{u}kler\/}: {\@anahtarsoz}.} \newpage}

\newenvironment{foreword}{%
   \thispagestyle{plain}
\parindent  0pt
   {\begin {center} {\fontsize{12pt}{12}  Foreword}\end{center}}
   \vspace{0.5cm} \noindent\ignorespaces} {\newpage} 

\newenvironment{ack}{%  Updated May: 2021 by Nann Win Moe Thet
   \thispagestyle{plain}
     \setstretch{1}
    % \setlength{\baselineskip}{6mm} %% updated {6mm}
   \parskip 6pt% 0.5cm 
\parindent 0pt
   {\fontsize{12pt}{12} \bfseries \MakeUppercase{Acknowledgement}\\}
   \vspace{0.5cm} \noindent\ignorespaces}{
    \vspace{2.5cm} 
\begin{flushleft}
\hfill{
 \@author\\}
\hfill{ \@submitmonth\\
}
\end{flushleft} {\newpage}} 

\newenvironment{dedication}{
   \thispagestyle{plain}
   \vspace*{40mm}
} {\newpage}




\def\@plagirismtext{I hereby declare that all information in this document has been obtained and
presented in accordance with academic rules and ethical conduct. I also declare that, as required by
these rules and conduct, I have fully cited and referenced all material and results that are not
original to this work.}
\def\@plagirismsignaturetext{Signature}
\def\@plagirismnametext{Name, Surname}
\def\plagiarism{
\newpage
\null
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
% \vspace*{\fill}
\vspace{11.4cm}
%\parindent0cm
%\ifd@uble\doublespacing\else\ifs@ngle\singlespacing\else\oneandhalfspacing\fi\fi
%\singlespacing
{\@plagirismtext}\\[1.25cm]   %% Updated May: 2021 by Nann Win Moe Thet
\begin{flushleft}
\hfill{
\begin{tabular}{l@{}ll}
{\@plagirismsignaturetext} & {:} & \\
{\@plagirismnametext} & {:} & \MakeUppercase{\@author} \\[1cm]
\end{tabular}
}
\vspace*{\fill}
\end{flushleft}
\newpage}



% Start with pagestyle{headings} in case front matter isn't processed
\pagestyle{headings}
\makeatother

\pagenumbering{roman}
\parskip 0.5cm
\parindent 0.5cm



